import React, { FC, ReactNode, useEffect, useState } from 'react';
import { Text, TouchableOpacity, View } from 'react-native';
import { Image } from 'expo-image';
import { createMaterialTopTabNavigator } from '@react-navigation/material-top-tabs';
import { NavigationProp } from '@react-navigation/native';

import { PageWrapper } from '../../../components';
import { Colors } from '../../../theme';
import { styles } from './styles';

import { API_HOST } from '../../../constants';

import { usePostGetProfileQuery } from '../../../modules/auth/user/queries/use-post-get-profile';

import { NAVIGATION_PAGES } from '../../../types';
import { navigationOpts } from './navigation-opts';

import { storageGet } from '../../../storage';

import PenIcon from '../../../../assets/icons/pen.svg';

import { getFontSize, getYears } from '../../../utils';

const regions = [
  {
    count: 28,
    name: 'NM1301'
  },
  {
    count: 1,
    name: 'M@P'
  },
  {
    count: 13,
    name: 'UN'
  },
  {
    count: 14,
    name: 'UN+'
  },
  {
    count: 16,
    name: 'TCC'
  },
  {
    count: 3,
    name: 'WHS'
  }
];

const Tab = createMaterialTopTabNavigator();

// TODO: refactor + connect with API

type Props = {
  navigation: NavigationProp<any>;
};

const ProfileScreen: FC<Props> = ({ navigation }) => {
  const [token, setToken] = useState<string>('');

  const { data, error } = usePostGetProfileQuery(token!, true);

  useEffect(() => {
    async function getToken() {
      const storageToken = await storageGet('token');
      setToken(storageToken as unknown as string);
    }

    getToken();
  }, []);

  if (!data) return <Text>Loading</Text>;

  return (
    <PageWrapper>
      <View style={styles.pageWrapper}>
        <View>
          <Image
            style={{ borderRadius: 64 / 2, width: 64, height: 64 }}
            source={{
              uri: API_HOST + '/img/avatars/' + data.avatar
            }}
          />
        </View>
        <View>
          <Text style={[styles.headerText, { fontSize: getFontSize(18) }]}>
            {data.first_name} {data.last_name}
          </Text>
          <View style={{ display: 'flex', flexDirection: 'row', alignItems: 'center', gap: 10 }}>
            <Image
              source={{
                uri: API_HOST + '/img/flags_new/' + data.homebase + '.png'
              }}
              style={styles.countryFlag}
            />
            <Image
              source={{
                uri: 'https://upload.wikimedia.org/wikipedia/commons/b/b6/Flag_of_Canada.png'
              }}
              style={[styles.countryFlag, { marginLeft: -15 }]}
            />
            <Text>Age: {getYears(data.date_of_birth)}</Text>
          </View>
        </View>
        <View>
          <TouchableOpacity
            style={{
              width: 40,
              height: 40,
              borderRadius: 40 / 2,
              borderWidth: 1,
              borderColor: Colors.LIGHT_GRAY,
              display: 'flex',
              justifyContent: 'center',
              alignItems: 'center'
            }}
            onPress={() => navigation.navigate(NAVIGATION_PAGES.EDIT_PERSONAL_INFO)}
          >
            <PenIcon />
          </TouchableOpacity>
        </View>
      </View>
      <Tab.Navigator
        screenOptions={{
          ...navigationOpts,
          tabBarLabel: ({ children, color, focused }) => (
            <Text style={[styles.headerText, { color }]}>{children}</Text>
          )
        }}
      >
        <Tab.Screen
          name="Personal Info"
          component={() => (
            <PersonalInfo data={{ bio: data.bio, date_of_birth: data.date_of_birth }} />
          )}
        />
        <Tab.Screen name="Visited Regions" component={() => <Text>Visited Regions</Text>} />
        <Tab.Screen name="Photos" component={() => <Text>Photos</Text>} />
      </Tab.Navigator>
    </PageWrapper>
  );
};

type PersonalInfoProps = {
  data: {
    bio: string;
    date_of_birth: string;
  };
};

const PersonalInfo: FC<PersonalInfoProps> = ({ data }) => {
  return (
    <View style={{ marginTop: 20, gap: 20 }}>
      <InfoItem inline={true} title={'Visited Regions'}>
        {regions.map((data) => (
          <View style={{ display: 'flex', flexDirection: 'column', gap: 5, alignItems: 'center' }}>
            <Text
              style={{
                fontFamily: 'redhat-700',
                color: Colors.DARK_BLUE,
                fontSize: getFontSize(14)
              }}
            >
              {data.count}
            </Text>
            <Text style={{ color: 'rgba(62, 100, 113, 1)', fontSize: getFontSize(12) }}>
              {data.name}
            </Text>
          </View>
        ))}
      </InfoItem>
      <View style={{ display: 'flex', flexDirection: 'row' }}>
        <Text
          style={{
            flex: 1,
            fontFamily: 'redhat-700',
            color: Colors.DARK_BLUE,
            fontSize: getFontSize(14)
          }}
        >
          Date of birth
        </Text>
        <Text
          style={{
            flex: 1,
            color: 'rgba(62, 100, 113, 1)',
            fontWeight: '400',
            fontSize: getFontSize(14)
          }}
        >
          {data.date_of_birth}
        </Text>
      </View>
      <View style={{ display: 'flex', flexDirection: 'row' }}>
        <Text
          style={{
            flex: 1,
            fontFamily: 'redhat-700',
            color: Colors.DARK_BLUE,
            fontSize: getFontSize(14)
          }}
        >
          Region of origin
        </Text>
        <Text
          style={{
            flex: 1,
            color: 'rgba(62, 100, 113, 1)',
            fontWeight: '400',
            fontSize: getFontSize(14)
          }}
        >
          Greece - Attica, Central and West (Athens, Lamia, Agrinio)
        </Text>
      </View>
      <InfoItem title={'Bio'}>
        <Text>{data.bio}</Text>
      </InfoItem>
      <InfoItem title={'Social links'}>
        <View style={{ display: 'flex', flexDirection: 'row', gap: 10 }}>
          <Image
            style={{ width: 20, height: 20 }}
            source={{
              uri: 'https://upload.wikimedia.org/wikipedia/commons/6/6c/Facebook_Logo_2023.png'
            }}
          />
          <Image
            style={{ width: 20, height: 20 }}
            source={{
              uri: 'https://upload.wikimedia.org/wikipedia/commons/a/a5/Instagram_icon.png'
            }}
          />
          <Image
            style={{ width: 20, height: 20 }}
            source={{
              uri: 'https://w7.pngwing.com/pngs/208/269/png-transparent-youtube-play-button-computer-icons-youtube-youtube-logo-angle-rectangle-logo-thumbnail.png'
            }}
          />
        </View>
      </InfoItem>
    </View>
  );
};

const InfoItem: FC<{ title: string; inline?: boolean; children: ReactNode }> = ({
  title,
  inline,
  children
}) => (
  <View>
    <Text style={styles.headerText}>{title}</Text>
    <View
      style={{
        display: 'flex',
        flexDirection: inline ? 'row' : 'column',
        justifyContent: 'space-evenly',
        marginTop: 10
      }}
    >
      {children}
    </View>
  </View>
);

export default ProfileScreen;
